@@ -94,8 +94,12 @@ void FilmasterFetcher::search() {
       u.setPath(u.path() + QLatin1String("person/"));
       break;
 
-    default:
+    case Keyword:
       break;
+
+    default:
+      stop();
+      return;
   }
   QUrlQuery q;
   q.addQueryItem(QStringLiteral("phrase"), request().value());
@@ -130,7 +134,9 @@ Tellico::Data::EntryPtr FilmasterFetcher::fetchEntryHook(uint uid_) {
   const QString image = entry->field(QStringLiteral("cover"));
   if(image.contains(QLatin1Char('/'))) {
     QUrl imageUrl;
-    if(image.startsWith(QLatin1String("//"))) {
+    if(image.startsWith(QLatin1String("http"))) {
+      imageUrl = QUrl(image);
+    } else if(image.startsWith(QLatin1String("//"))) {
       imageUrl = QUrl(QLatin1String("http:") + image);
     } else {
       imageUrl = QUrl(QString::fromLatin1(FILMASTER_API_URL));
@@ -236,7 +242,7 @@ void FilmasterFetcher::slotComplete(KJob* job_) {
   }
 
   foreach(const QVariant& result, resultList) {
-  //  myDebug() << "found result:" << result;
+//    myDebug() << "found result:" << result;
     Data::EntryPtr entry(new Data::Entry(coll));
     populateEntry(entry, result.toMap());
 
