@@ -29,12 +29,16 @@
 
 #include <QWidget>
 #include <QPixmap>
+#include <QImage>
 #include <QPoint>
 #include <QDateTime>
 #include <QPointer>
 #include <QUrl>
 
 #include <config.h>
+#ifdef HAVE_KSANE
+#include <ksane_version.h>
+#endif
 
 class QLabel;
 class QResizeEvent;
@@ -86,13 +90,22 @@ private Q_SLOTS:
   void slotGetImage();
   void slotLinkOnlyClicked();
   void slotScanImage();
+#ifdef HAVE_KSANE
+#if KSANE_VERSION < QT_VERSION_CHECK(21,8,0)
   void imageReady(QByteArray &data, int w, int h, int bpl, int f);
+#else
+  void imageReady(const QImage& scannedImage);
+#endif
+#endif
   void slotEditImage();
   void slotEditMenu(QAction* action);
   void slotFinished();
   void cancelScan();
+  void copyImage();
+  void saveImageAs();
 
 private:
+  void contextMenuEvent(QContextMenuEvent* event) Q_DECL_OVERRIDE;
   void scale();
   void loadImage(const QUrl& url);
 
