@@ -27,7 +27,6 @@
 #include "../core/filehandler.h"
 #include "../utils/cursorsaver.h"
 #include "../utils/tellico_utils.h"
-#include "../tellico_kernel.h"
 #include "../tellico_debug.h"
 
 #include <KTar>
@@ -119,7 +118,7 @@ bool Manager::installTemplate(const QString& file_) {
     if(QFile::exists(name)) {
       QFile::remove(name);
     }
-    KIO::Job* job = KIO::file_copy(QUrl::fromLocalFile(file_), QUrl::fromLocalFile(name));
+    auto job = KIO::file_copy(QUrl::fromLocalFile(file_), QUrl::fromLocalFile(name));
     if(job->exec()) {
       xslFile = QFileInfo(name).fileName();
       allFiles << xslFile;
@@ -162,7 +161,7 @@ bool Manager::removeTemplateByName(const QString& name_) {
     KConfigGroup config(KSharedConfig::openConfig(), "KNewStuffFiles");
     QString file = config.readEntry(xslFile, QString());
     if(!file.isEmpty()) {
-      return removeTemplate(file, true);
+      return removeTemplate(file);
     }
     // At least remove xsl file
     QFile::remove(Tellico::saveLocation(QStringLiteral("entry-templates/")) + xslFile);
@@ -171,7 +170,7 @@ bool Manager::removeTemplateByName(const QString& name_) {
   return false;
 }
 
-bool Manager::removeTemplate(const QString& file_, bool manual_) {
+bool Manager::removeTemplate(const QString& file_) {
   if(file_.isEmpty()) {
     return false;
   }
@@ -203,43 +202,11 @@ bool Manager::removeTemplate(const QString& file_, bool manual_) {
   fileGroup.deleteEntry(file_);
   QString key = fileGroup.entryMap().key(file_);
   fileGroup.deleteEntry(key);
-
-  if(manual_) {
-    removeNewStuffFile(file_);
-  }
+  KSharedConfig::openConfig()->sync();
   return success;
 }
 
-void Manager::removeNewStuffFile(const QString& file_) {
-//TODO KF5
-  Q_UNUSED(file_);
-#if 0
-  DEBUG_BLOCK;
-  if(file_.isEmpty()) {
-    return;
-  }
-  // remove newstuff meta file if that exists
-  QString newStuffDir = dirs.writableLocation("data", QLatin1String("knewstuff2-entries.registry/"));
-  QStringList metaFiles = QDir(newStuffDir).entryList(QStringList() << QLatin1String("*.meta"), QDir::Files);
-  QByteArray start = QString::fromLatin1(" <ghnsinstall payloadfile=\"%1\"").arg(file_).toUtf8();
-  foreach(const QString& meta, metaFiles) {
-    QFile f(newStuffDir + meta);
-    if(f.open(QIODevice::ReadOnly)) {
-      QByteArray firstLine = f.readLine();
-      if(firstLine.startsWith(start)) {
-        f.remove();
-        // It was newstuff file so remove payload also
-        QFile::remove(file_);
-        break;
-      }
-      f.close();
-    }
-  }
-#endif
-}
-
 bool Manager::installScript(const QString& file_) {
-  DEBUG_BLOCK;
   if(file_.isEmpty()) {
     return false;
   }
@@ -292,7 +259,7 @@ bool Manager::installScript(const QString& file_) {
     copyTarget += sourceName;
     scriptFolder = copyTarget + QDir::separator();
     QDir().mkpath(scriptFolder);
-    KIO::Job* job = KIO::file_copy(QUrl::fromLocalFile(file_), QUrl::fromLocalFile(scriptFolder + exeFile));
+    auto job = KIO::file_copy(QUrl::fromLocalFile(file_), QUrl::fromLocalFile(scriptFolder + exeFile));
     if(!job->exec()) {
       myDebug() << "Copy failed";
       return false;
@@ -327,7 +294,7 @@ bool Manager::installScript(const QString& file_) {
   //  myDebug() << "specFile = " << info->specFile;
   KConfigGroup configGroup(KSharedConfig::openConfig(), QStringLiteral("Data Sources"));
   int nSources = configGroup.readEntry("Sources Count", 0);
-  config.writeEntry(file_ + QLatin1String("_nbr"), nSources);
+  config.writeEntry(sourceName + QLatin1String("_nbr"), nSources);
   configGroup.writeEntry("Sources Count", nSources + 1);
   KConfigGroup sourceGroup(KSharedConfig::openConfig(), QStringLiteral("Data Source %1").arg(nSources));
   sourceGroup.writeEntry("Name", sourceName);
@@ -339,7 +306,6 @@ bool Manager::installScript(const QString& file_) {
 }
 
 bool Manager::removeScriptByName(const QString& name_) {
-//  DEBUG_BLOCK;
   if(name_.isEmpty()) {
     return false;
   }
@@ -347,25 +313,34 @@ bool Manager::removeScriptByName(const QString& name_) {
   KConfigGroup config(KSharedConfig::openConfig(), "KNewStuffFiles");
   QString file = config.readEntry(name_, QString());
   if(!file.isEmpty()) {
-    return removeScript(file, true);
+    return removeScript(file);
   }
   return false;
 }
 
-bool Manager::removeScript(const QString& file_, bool manual_) {
-  DEBUG_BLOCK;
+bool Manager::removeScript(const QString& file_) {
   if(file_.isEmpty()) {
     return false;
   }
   GUI::CursorSaver cs;
 
+  QFileInfo fi(file_);
+  const QString realFile = fi.fileName();
+  const QString sourceName = fi.completeBaseName();
+
   bool success = true;
   KConfigGroup fileGroup(KSharedConfig::openConfig(), "KNewStuffFiles");
   QString scriptFolder = fileGroup.readEntry(file_, QString());
+  if(scriptFolder.isEmpty()) {
+    scriptFolder = fileGroup.readEntry(realFile, QString());
+  }
   int source = fileGroup.readEntry(file_ + QLatin1String("_nbr"), -1);
+  if(source == -1) {
+    source = fileGroup.readEntry(sourceName + QLatin1String("_nbr"), -1);
+  }
 
   if(!scriptFolder.isEmpty()) {
-    KIO::del(QUrl::fromLocalFile(scriptFolder));
+    KIO::del(QUrl::fromLocalFile(scriptFolder))->exec();
   }
   if(source != -1) {
     KConfigGroup configGroup(KSharedConfig::openConfig(), QStringLiteral("Data Sources"));
@@ -374,13 +349,17 @@ bool Manager::removeScript(const QString& file_, bool manual_) {
     KConfigGroup sourceGroup(KSharedConfig::openConfig(), QStringLiteral("Data Source %1").arg(source));
     sourceGroup.deleteGroup();
   }
+
   // remove config entries even if unsuccessful
   fileGroup.deleteEntry(file_);
   QString key = fileGroup.entryMap().key(file_);
-  fileGroup.deleteEntry(key);
-  if(manual_) {
-    removeNewStuffFile(file_);
-  }
+  if(!key.isEmpty()) fileGroup.deleteEntry(key);
+  fileGroup.deleteEntry(realFile);
+  key = fileGroup.entryMap().key(realFile);
+  if(!key.isEmpty()) fileGroup.deleteEntry(key);
+  fileGroup.deleteEntry(file_ + QLatin1String("_nbr"));
+  fileGroup.deleteEntry(sourceName + QLatin1String("_nbr"));
+  KSharedConfig::openConfig()->sync();
   return success;
 }
 
