@@ -23,7 +23,6 @@
  ***************************************************************************/
 
 #include "tellico_kernel.h"
-#include "mainwindow.h"
 #include "document.h"
 #include "collection.h"
 #include "controller.h"
@@ -43,6 +42,7 @@
 #include "collectionfactory.h"
 #include "utils/stringset.h"
 #include "utils/cursorsaver.h"
+#include "utils/mergeconflictresolver.h"
 
 #include <KMessageBox>
 #include <KLocalizedString>
@@ -53,7 +53,7 @@
 using Tellico::Kernel;
 Kernel* Kernel::s_self = nullptr;
 
-Kernel::Kernel(Tellico::MainWindow* parent) : m_widget(parent)
+Kernel::Kernel(QWidget* parent) : m_widget(parent)
     , m_commandHistory(new QUndoStack(parent)) {
 }
 
@@ -64,22 +64,6 @@ QUrl Kernel::URL() const {
   return Data::Document::self()->URL();
 }
 
-QStringList Kernel::fieldTitles() const {
-  return Data::Document::self()->collection()->fieldTitles();
-}
-
-QString Kernel::fieldNameByTitle(const QString& title_) const {
-  return Data::Document::self()->collection()->fieldNameByTitle(title_);
-}
-
-QString Kernel::fieldTitleByName(const QString& name_) const {
-  return Data::Document::self()->collection()->fieldTitleByName(name_);
-}
-
-QStringList Kernel::valuesByFieldName(const QString& name_) const {
-  return Data::Document::self()->collection()->valuesByFieldName(name_);
-}
-
 int Kernel::collectionType() const {
   return Data::Document::self()->collection() ?
          Data::Document::self()->collection()->type() :
@@ -90,7 +74,7 @@ QString Kernel::collectionTypeName() const {
   return CollectionFactory::typeName(collectionType());
 }
 
-void Kernel::sorry(const QString& text_, QWidget* widget_/* =0 */) {
+void Kernel::sorry(const QString& text_, QWidget* widget_/* =nullptr */) {
   if(text_.isEmpty()) {
     return;
   }
@@ -159,7 +143,7 @@ void Kernel::addEntries(Tellico::Data::EntryList entries_, bool checkFields_) {
     Tellico::Data::CollPtr c = Data::Document::self()->collection();
     Tellico::Data::FieldList fields = entries_[0]->collection()->fields();
 
-    QPair<Tellico::Data::FieldList, Tellico::Data::FieldList> p = Data::Document::mergeFields(c, fields, entries_);
+    auto p = Merge::mergeFields(c, fields, entries_);
     Data::FieldList modifiedFields = p.first;
     Data::FieldList addedFields = p.second;
 
@@ -359,9 +343,9 @@ int Kernel::askAndMerge(Tellico::Data::EntryPtr entry1_, Tellico::Data::EntryPtr
                                             KGuiItem(i18n("Select value from %1", title1)),
                                             KGuiItem(i18n("Select value from %1", title2)));
   switch(ret) {
-    case KMessageBox::Cancel: return MergeConflictResolver::CancelMerge;
-    case KMessageBox::Yes: return MergeConflictResolver::KeepFirst; // keep original value
-    case KMessageBox::No: return MergeConflictResolver::KeepSecond; // use newer value
+    case KMessageBox::Cancel: return Merge::ConflictResolver::CancelMerge;
+    case KMessageBox::Yes: return Merge::ConflictResolver::KeepFirst; // keep original value
+    case KMessageBox::No: return Merge::ConflictResolver::KeepSecond; // use newer value
   }
-  return MergeConflictResolver::CancelMerge;
+  return Merge::ConflictResolver::CancelMerge;
 }
