@@ -26,7 +26,6 @@
 
 #include "boardgamegeekfetchertest.h"
 
-#include "../fetch/execexternalfetcher.h"
 #include "../fetch/boardgamegeekfetcher.h"
 #include "../collections/boardgamecollection.h"
 #include "../collectionfactory.h"
@@ -70,6 +69,7 @@ void BoardGameGeekFetcherTest::testTitle() {
   QVERIFY(!entry->field(QStringLiteral("cover")).isEmpty());
   QVERIFY(!entry->field(QStringLiteral("cover")).contains(QLatin1Char('/')));
   QVERIFY(!entry->field(QStringLiteral("description")).isEmpty());
+  QCOMPARE(entry->field(QStringLiteral("boardgamegeek-link")), QStringLiteral("https://www.boardgamegeek.com/boardgame/13"));
 }
 
 void BoardGameGeekFetcherTest::testKeyword() {
