@@ -34,9 +34,11 @@ public:
 
 private Q_SLOTS:
   void initTestCase();
+  void testTitle();
   void testIsbn();
   void testIsbn13();
   void testMultipleIsbn();
+  void testUpdate();
 };
 
 #endif
