@@ -58,7 +58,7 @@ public:
   static bool maybeRIS(const QUrl& url);
 
 public Q_SLOTS:
-  void slotCancel();
+  void slotCancel() Q_DECL_OVERRIDE;
 
 private:
   static void initTagMap();
