@@ -25,7 +25,7 @@
 #ifndef TELLICO_IMPORT_XMLSTATEHANDLER_H
 #define TELLICO_IMPORT_XMLSTATEHANDLER_H
 
-#include <QXmlAttributes>
+#include <QXmlStreamAttributes>
 
 #include "../datavectors.h"
 
@@ -62,15 +62,15 @@ public:
   StateHandler(StateData* data) : d(data) {}
   virtual ~StateHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) = 0;
-  virtual bool   end(const QString&, const QString&, const QString&) = 0;
+  virtual bool start(const QStringRef& nsUri, const QStringRef& localName, const QXmlStreamAttributes& attributes) = 0;
+  virtual bool   end(const QStringRef& nsUri, const QStringRef& localName) = 0;
 
-  StateHandler* nextHandler(const QString&, const QString&, const QString&);
+  StateHandler* nextHandler(const QStringRef& nsUri, const QStringRef& localName);
 protected:
   StateData* d;
 private:
   Q_DISABLE_COPY(StateHandler)
-  virtual StateHandler* nextHandlerImpl(const QString&, const QString&, const QString&)  { return nullptr; }
+  virtual StateHandler* nextHandlerImpl(const QStringRef&, const QStringRef&)  { return nullptr; }
 };
 
 class NullHandler : public StateHandler {
@@ -78,8 +78,8 @@ public:
   NullHandler(StateData* data) : StateHandler(data) {}
   virtual ~NullHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE { return true; }
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE { return true; }
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE { return true; }
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE { return true; }
 };
 
 class RootHandler : public StateHandler {
@@ -87,11 +87,11 @@ public:
   RootHandler(StateData* data) : StateHandler(data) {}
   virtual ~RootHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE { return true; }
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE { return true; }
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE { return true; }
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE { return true; }
 
 private:
-  virtual StateHandler* nextHandlerImpl(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual StateHandler* nextHandlerImpl(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 };
 
 class DocumentHandler : public StateHandler {
@@ -99,11 +99,11 @@ public:
   DocumentHandler(StateData* data) : StateHandler(data) {}
   virtual ~DocumentHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 
 private:
-  virtual StateHandler* nextHandlerImpl(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual StateHandler* nextHandlerImpl(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 };
 
 class CollectionHandler : public StateHandler {
@@ -111,11 +111,11 @@ public:
   CollectionHandler(StateData* data) : StateHandler(data) {}
   virtual ~CollectionHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 
 private:
-  virtual StateHandler* nextHandlerImpl(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual StateHandler* nextHandlerImpl(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 };
 
 class FieldsHandler : public StateHandler {
@@ -123,11 +123,11 @@ public:
   FieldsHandler(StateData* data) : StateHandler(data) {}
   virtual ~FieldsHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 
 private:
-  virtual StateHandler* nextHandlerImpl(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual StateHandler* nextHandlerImpl(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 };
 
 class FieldHandler : public StateHandler {
@@ -135,11 +135,11 @@ public:
   FieldHandler(StateData* data) : StateHandler(data) {}
   virtual ~FieldHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 
 private:
-  virtual StateHandler* nextHandlerImpl(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual StateHandler* nextHandlerImpl(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 };
 
 class FieldPropertyHandler : public StateHandler {
@@ -147,8 +147,8 @@ public:
   FieldPropertyHandler(StateData* data) : StateHandler(data) {}
   virtual ~FieldPropertyHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 
 private:
   QString m_propertyName;
@@ -159,8 +159,8 @@ public:
   BibtexPreambleHandler(StateData* data) : StateHandler(data) {}
   virtual ~BibtexPreambleHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 };
 
 class BibtexMacrosHandler : public StateHandler {
@@ -168,11 +168,11 @@ public:
   BibtexMacrosHandler(StateData* data) : StateHandler(data) {}
   virtual ~BibtexMacrosHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 
 private:
-  virtual StateHandler* nextHandlerImpl(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual StateHandler* nextHandlerImpl(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 };
 
 class BibtexMacroHandler : public StateHandler {
@@ -180,8 +180,8 @@ public:
   BibtexMacroHandler(StateData* data) : StateHandler(data) {}
   virtual ~BibtexMacroHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 
 private:
   QString m_macroName;
@@ -192,11 +192,11 @@ public:
   EntryHandler(StateData* data) : StateHandler(data) {}
   virtual ~EntryHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 
 private:
-  virtual StateHandler* nextHandlerImpl(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual StateHandler* nextHandlerImpl(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 };
 
 class FieldValueContainerHandler : public StateHandler {
@@ -204,11 +204,11 @@ public:
   FieldValueContainerHandler(StateData* data) : StateHandler(data) {}
   virtual ~FieldValueContainerHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 
 private:
-  virtual StateHandler* nextHandlerImpl(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual StateHandler* nextHandlerImpl(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 };
 
 class FieldValueHandler : public StateHandler {
@@ -217,11 +217,11 @@ public:
     , m_i18n(false), m_validateISBN(false) {}
   virtual ~FieldValueHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 
 private:
-  virtual StateHandler* nextHandlerImpl(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual StateHandler* nextHandlerImpl(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
   bool m_i18n;
   bool m_validateISBN;
 };
@@ -231,8 +231,8 @@ public:
   DateValueHandler(StateData* data) : StateHandler(data) {}
   virtual ~DateValueHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 };
 
 class TableColumnHandler : public StateHandler {
@@ -240,8 +240,8 @@ public:
   TableColumnHandler(StateData* data) : StateHandler(data) {}
   virtual ~TableColumnHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 };
 
 class ImagesHandler : public StateHandler {
@@ -249,11 +249,11 @@ public:
   ImagesHandler(StateData* data) : StateHandler(data) {}
   virtual ~ImagesHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 
 private:
-  virtual StateHandler* nextHandlerImpl(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual StateHandler* nextHandlerImpl(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 };
 
 class ImageHandler : public StateHandler {
@@ -262,8 +262,8 @@ public:
     , m_link(false), m_width(0), m_height(0) {}
   virtual ~ImageHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 
 private:
   QString m_format;
@@ -278,11 +278,11 @@ public:
   FiltersHandler(StateData* data) : StateHandler(data) {}
   virtual ~FiltersHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 
 private:
-  virtual StateHandler* nextHandlerImpl(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual StateHandler* nextHandlerImpl(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 };
 
 class FilterHandler : public StateHandler {
@@ -290,11 +290,11 @@ public:
   FilterHandler(StateData* data) : StateHandler(data) {}
   virtual ~FilterHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 
 private:
-  virtual StateHandler* nextHandlerImpl(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual StateHandler* nextHandlerImpl(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 };
 
 class FilterRuleHandler : public StateHandler {
@@ -302,8 +302,8 @@ public:
   FilterRuleHandler(StateData* data) : StateHandler(data) {}
   virtual ~FilterRuleHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 };
 
 class BorrowersHandler : public StateHandler {
@@ -311,11 +311,11 @@ public:
   BorrowersHandler(StateData* data) : StateHandler(data) {}
   virtual ~BorrowersHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 
 private:
-  virtual StateHandler* nextHandlerImpl(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual StateHandler* nextHandlerImpl(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 };
 
 class BorrowerHandler : public StateHandler {
@@ -323,11 +323,11 @@ public:
   BorrowerHandler(StateData* data) : StateHandler(data) {}
   virtual ~BorrowerHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 
 private:
-  virtual StateHandler* nextHandlerImpl(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual StateHandler* nextHandlerImpl(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 };
 
 class LoanHandler : public StateHandler {
@@ -336,8 +336,8 @@ public:
     , m_id(-1), m_inCalendar(false) {}
   virtual ~LoanHandler() {}
 
-  virtual bool start(const QString&, const QString&, const QString&, const QXmlAttributes&) Q_DECL_OVERRIDE;
-  virtual bool   end(const QString&, const QString&, const QString&) Q_DECL_OVERRIDE;
+  virtual bool start(const QStringRef&, const QStringRef&, const QXmlStreamAttributes&) Q_DECL_OVERRIDE;
+  virtual bool   end(const QStringRef&, const QStringRef&) Q_DECL_OVERRIDE;
 
 private:
   int m_id;
